@@ -5,9 +5,9 @@ from typing import List
 from singer_sdk import Stream, Tap
 from singer_sdk import typing as th
 
-from tap_zammad.streams import TagsStream, TicketsStream, UsersStream
+from tap_zammad.streams import GroupsStream, TagsStream, TicketsStream, UsersStream
 
-STREAM_TYPES = [TicketsStream, TagsStream, UsersStream]
+STREAM_TYPES = [TicketsStream, TagsStream, UsersStream, GroupsStream]
 
 
 class TapZammad(Tap):
@@ -21,6 +21,7 @@ class TapZammad(Tap):
             th.StringType,
             required=True,
             description="The token to authenticate against the Zammad API",
+            secret=True,
         ),
         th.Property(
             "start_date",
@@ -33,16 +34,6 @@ class TapZammad(Tap):
             description="The base url of the Zammad API",
             required=True,
         ),
-        th.Property(
-            "retrieve_tickets_tags",
-            th.BooleanType,
-            description=(
-                "Wether to retrieve tags for a ticket. "
-                "Can significantly slow sync process as tags"
-                " endpoint has to be requested for each ticket."
-            ),
-            default=False,
-        ),
     ).to_dict()
 
     def discover_streams(self) -> List[Stream]:
